sequencetools.split_sequence_extended_to_weights
================================================

.. autofunction:: abjad.tools.sequencetools.split_sequence_extended_to_weights.split_sequence_extended_to_weights
